"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from dataclasses_json import Undefined, dataclass_json
from leonardoaisdk import utils
from typing import Optional


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class ElementInput:
    ak_uuid: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('akUUID') }})
    r"""Unique identifier for element. Elements can be found from the List Elements endpoint."""
    weight: Optional[float] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('weight') }})
    r"""Weight for the element"""
    




"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import requests as requests_http
from dataclasses_json import Undefined, dataclass_json
from leonardoaisdk import utils
from typing import Optional


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class UploadInitImageRequestBody:
    r"""Query parameters provided in the request body as a JSON object"""
    extension: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('extension') }})
    r"""Has to be png, jpg, jpeg, or webp."""
    



@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class UploadInitImage200ApplicationJSONInitImageUploadOutput:
    fields_: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('fields') }})
    id: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('id') }})
    key: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('key') }})
    url: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('url') }})
    



@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class UploadInitImage200ApplicationJSON:
    r"""Responses for POST /init-image"""
    upload_init_image: Optional[UploadInitImage200ApplicationJSONInitImageUploadOutput] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('uploadInitImage') }})
    



@dataclasses.dataclass
class UploadInitImageResponse:
    content_type: str = dataclasses.field()
    r"""HTTP response content type for this operation"""
    status_code: int = dataclasses.field()
    r"""HTTP response status code for this operation"""
    raw_response: Optional[requests_http.Response] = dataclasses.field(default=None)
    r"""Raw HTTP response; suitable for custom response parsing"""
    upload_init_image_200_application_json_object: Optional[UploadInitImage200ApplicationJSON] = dataclasses.field(default=None)
    r"""Responses for POST /init-image"""
    




"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import requests as requests_http
from dataclasses_json import Undefined, dataclass_json
from leonardoaisdk import utils
from typing import Optional


@dataclasses.dataclass
class DeleteDatasetByIDRequest:
    id: str = dataclasses.field(metadata={'path_param': { 'field_name': 'id', 'style': 'simple', 'explode': False }})
    r"""The ID of the dataset to delete."""
    



@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class DeleteDatasetByID200ApplicationJSONDatasets:
    r"""columns and relationships of \\"datasets\\" """
    id: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('id') }})
    



@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class DeleteDatasetByID200ApplicationJSON:
    r"""Responses for DELETE /datasets/{id}"""
    delete_datasets_by_pk: Optional[DeleteDatasetByID200ApplicationJSONDatasets] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('delete_datasets_by_pk') }})
    r"""columns and relationships of \\"datasets\\" """
    



@dataclasses.dataclass
class DeleteDatasetByIDResponse:
    content_type: str = dataclasses.field()
    r"""HTTP response content type for this operation"""
    status_code: int = dataclasses.field()
    r"""HTTP response status code for this operation"""
    delete_dataset_by_id_200_application_json_object: Optional[DeleteDatasetByID200ApplicationJSON] = dataclasses.field(default=None)
    r"""Responses for DELETE /datasets/{id}"""
    raw_response: Optional[requests_http.Response] = dataclasses.field(default=None)
    r"""Raw HTTP response; suitable for custom response parsing"""
    




"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import requests as requests_http
from ..shared import job_status as shared_job_status
from ..shared import model_asset_texture_types as shared_model_asset_texture_types
from dataclasses_json import Undefined, dataclass_json
from leonardoaisdk import utils
from typing import List, Optional


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class GetGenerationsTextureModelModelIDRequestBody:
    r"""Query parameters can also be provided in the request body as a JSON object"""
    limit: Optional[int] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('limit') }})
    model_id: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('modelId') }})
    offset: Optional[int] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('offset') }})
    



@dataclasses.dataclass
class GetGenerationsTextureModelModelIDRequest:
    model_id: str = dataclasses.field(metadata={'path_param': { 'field_name': 'modelId', 'style': 'simple', 'explode': False }})
    r"""_\\"modelId\\" is required (enter it either in parameters or request body)_"""
    limit: Optional[int] = dataclasses.field(default=10, metadata={'query_param': { 'field_name': 'limit', 'style': 'form', 'explode': True }})
    offset: Optional[int] = dataclasses.field(default=0, metadata={'query_param': { 'field_name': 'offset', 'style': 'form', 'explode': True }})
    request_body: Optional[GetGenerationsTextureModelModelIDRequestBody] = dataclasses.field(default=None, metadata={'request': { 'media_type': 'application/json' }})
    r"""Query parameters can also be provided in the request body as a JSON object"""
    



@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class GetGenerationsTextureModelModelID200ApplicationJSONModelAssetTextureGenerationsModelAssetTextureImages:
    r"""columns and relationships of \\"model_asset_texture_images\\" """
    id: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('id') }})
    type: Optional[shared_model_asset_texture_types.ModelAssetTextureTypes] = dataclasses.field(default=shared_model_asset_texture_types.ModelAssetTextureTypes.NORMAL, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('type'), 'exclude': lambda f: f is None }})
    r"""When training model assets these are the texture types available to use."""
    url: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('url'), 'exclude': lambda f: f is None }})
    



@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class GetGenerationsTextureModelModelID200ApplicationJSONModelAssetTextureGenerations:
    r"""columns and relationships of \\"model_asset_texture_generations\\" """
    created_at: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('createdAt'), 'exclude': lambda f: f is None }})
    id: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('id') }})
    model_asset_texture_images: Optional[List[GetGenerationsTextureModelModelID200ApplicationJSONModelAssetTextureGenerationsModelAssetTextureImages]] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('model_asset_texture_images'), 'exclude': lambda f: f is None }})
    negative_prompt: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('negativePrompt') }})
    prompt: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('prompt'), 'exclude': lambda f: f is None }})
    seed: Optional[int] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('seed') }})
    status: Optional[shared_job_status.JobStatus] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('status'), 'exclude': lambda f: f is None }})
    r"""The status of the current task."""
    



@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class GetGenerationsTextureModelModelID200ApplicationJSON:
    r"""Responses for GET /api/rest/v1/generations-texture/model/{modelId}"""
    model_asset_texture_generations: Optional[List[GetGenerationsTextureModelModelID200ApplicationJSONModelAssetTextureGenerations]] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('model_asset_texture_generations'), 'exclude': lambda f: f is None }})
    



@dataclasses.dataclass
class GetGenerationsTextureModelModelIDResponse:
    content_type: str = dataclasses.field()
    r"""HTTP response content type for this operation"""
    status_code: int = dataclasses.field()
    r"""HTTP response status code for this operation"""
    get_generations_texture_model_model_id_200_application_json_object: Optional[GetGenerationsTextureModelModelID200ApplicationJSON] = dataclasses.field(default=None)
    r"""Responses for GET /api/rest/v1/generations-texture/model/{modelId}"""
    raw_response: Optional[requests_http.Response] = dataclasses.field(default=None)
    r"""Raw HTTP response; suitable for custom response parsing"""
    




"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from .sdkconfiguration import SDKConfiguration
from leonardoaisdk import utils
from leonardoaisdk.models import errors, operations
from typing import Optional

class Model:
    sdk_configuration: SDKConfiguration

    def __init__(self, sdk_config: SDKConfiguration) -> None:
        self.sdk_configuration = sdk_config
        
    
    def create_model(self, request: operations.CreateModelRequestBody) -> operations.CreateModelResponse:
        r"""Train a Custom Model
        This endpoint will train a new custom model
        """
        base_url = utils.template_url(*self.sdk_configuration.get_server_details())
        
        url = base_url + '/models'
        headers = {}
        req_content_type, data, form = utils.serialize_request_body(request, "request", False, False, 'json')
        if req_content_type not in ('multipart/form-data', 'multipart/mixed'):
            headers['content-type'] = req_content_type
        if data is None and form is None:
            raise Exception('request body is required')
        headers['Accept'] = 'application/json'
        headers['user-agent'] = self.sdk_configuration.user_agent
        
        client = self.sdk_configuration.security_client
        
        http_res = client.request('POST', url, data=data, files=form, headers=headers)
        content_type = http_res.headers.get('Content-Type')

        res = operations.CreateModelResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 200:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.CreateModel200ApplicationJSON])
                res.create_model_200_application_json_object = out
            else:
                raise errors.SDKError(f'unknown content-type received: {content_type}', http_res.status_code, http_res.text, http_res)

        return res

    
    def delete_model_by_id(self, id: str) -> operations.DeleteModelByIDResponse:
        r"""Delete a Single Custom Model by ID
        This endpoint will delete a specific custom model
        """
        request = operations.DeleteModelByIDRequest(
            id=id,
        )
        
        base_url = utils.template_url(*self.sdk_configuration.get_server_details())
        
        url = utils.generate_url(operations.DeleteModelByIDRequest, base_url, '/models/{id}', request)
        headers = {}
        headers['Accept'] = 'application/json'
        headers['user-agent'] = self.sdk_configuration.user_agent
        
        client = self.sdk_configuration.security_client
        
        http_res = client.request('DELETE', url, headers=headers)
        content_type = http_res.headers.get('Content-Type')

        res = operations.DeleteModelByIDResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 200:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.DeleteModelByID200ApplicationJSON])
                res.delete_model_by_id_200_application_json_object = out
            else:
                raise errors.SDKError(f'unknown content-type received: {content_type}', http_res.status_code, http_res.text, http_res)

        return res

    
    def delete_models_3d_id_(self, id: str, request_body: Optional[operations.DeleteModels3dIDRequestBody] = None) -> operations.DeleteModels3dIDResponse:
        r"""Delete 3D Model by ID
        This endpoint deletes the specific 3D Model
        """
        request = operations.DeleteModels3dIDRequest(
            id=id,
            request_body=request_body,
        )
        
        base_url = utils.template_url(*self.sdk_configuration.get_server_details())
        
        url = utils.generate_url(operations.DeleteModels3dIDRequest, base_url, '/models-3d/{id}', request)
        headers = {}
        req_content_type, data, form = utils.serialize_request_body(request, "request_body", False, True, 'json')
        if req_content_type not in ('multipart/form-data', 'multipart/mixed'):
            headers['content-type'] = req_content_type
        headers['Accept'] = 'application/json'
        headers['user-agent'] = self.sdk_configuration.user_agent
        
        client = self.sdk_configuration.security_client
        
        http_res = client.request('DELETE', url, data=data, files=form, headers=headers)
        content_type = http_res.headers.get('Content-Type')

        res = operations.DeleteModels3dIDResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 200:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.DeleteModels3dID200ApplicationJSON])
                res.delete_models_3d_id_200_application_json_object = out
            else:
                raise errors.SDKError(f'unknown content-type received: {content_type}', http_res.status_code, http_res.text, http_res)

        return res

    
    def get_model_by_id(self, id: str) -> operations.GetModelByIDResponse:
        r"""Get a Single Custom Model by ID
        This endpoint gets the specific custom model
        """
        request = operations.GetModelByIDRequest(
            id=id,
        )
        
        base_url = utils.template_url(*self.sdk_configuration.get_server_details())
        
        url = utils.generate_url(operations.GetModelByIDRequest, base_url, '/models/{id}', request)
        headers = {}
        headers['Accept'] = 'application/json'
        headers['user-agent'] = self.sdk_configuration.user_agent
        
        client = self.sdk_configuration.security_client
        
        http_res = client.request('GET', url, headers=headers)
        content_type = http_res.headers.get('Content-Type')

        res = operations.GetModelByIDResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 200:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.GetModelByID200ApplicationJSON])
                res.get_model_by_id_200_application_json_object = out
            else:
                raise errors.SDKError(f'unknown content-type received: {content_type}', http_res.status_code, http_res.text, http_res)

        return res

    
    def get_models_3d_user_user_id_(self, user_id: str, request_body: Optional[operations.GetModels3dUserUserIDRequestBody] = None, limit: Optional[int] = None, offset: Optional[int] = None) -> operations.GetModels3dUserUserIDResponse:
        r"""Get 3D models by user ID
        This endpoint returns all 3D models by a specific user
        """
        request = operations.GetModels3dUserUserIDRequest(
            user_id=user_id,
            request_body=request_body,
            limit=limit,
            offset=offset,
        )
        
        base_url = utils.template_url(*self.sdk_configuration.get_server_details())
        
        url = utils.generate_url(operations.GetModels3dUserUserIDRequest, base_url, '/models-3d/user/{userId}', request)
        headers = {}
        req_content_type, data, form = utils.serialize_request_body(request, "request_body", False, True, 'json')
        if req_content_type not in ('multipart/form-data', 'multipart/mixed'):
            headers['content-type'] = req_content_type
        query_params = utils.get_query_params(operations.GetModels3dUserUserIDRequest, request)
        headers['Accept'] = 'application/json'
        headers['user-agent'] = self.sdk_configuration.user_agent
        
        client = self.sdk_configuration.security_client
        
        http_res = client.request('GET', url, params=query_params, data=data, files=form, headers=headers)
        content_type = http_res.headers.get('Content-Type')

        res = operations.GetModels3dUserUserIDResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 200:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.GetModels3dUserUserID200ApplicationJSON])
                res.get_models_3d_user_user_id_200_application_json_object = out
            else:
                raise errors.SDKError(f'unknown content-type received: {content_type}', http_res.status_code, http_res.text, http_res)

        return res

    
    def get_models_3d_id_(self, id: str, request_body: Optional[operations.GetModels3dIDRequestBody] = None, limit: Optional[int] = None, offset: Optional[int] = None) -> operations.GetModels3dIDResponse:
        r"""Get 3D Model by ID
        This endpoint gets the specific 3D model
        """
        request = operations.GetModels3dIDRequest(
            id=id,
            request_body=request_body,
            limit=limit,
            offset=offset,
        )
        
        base_url = utils.template_url(*self.sdk_configuration.get_server_details())
        
        url = utils.generate_url(operations.GetModels3dIDRequest, base_url, '/models-3d/{id}', request)
        headers = {}
        req_content_type, data, form = utils.serialize_request_body(request, "request_body", False, True, 'json')
        if req_content_type not in ('multipart/form-data', 'multipart/mixed'):
            headers['content-type'] = req_content_type
        query_params = utils.get_query_params(operations.GetModels3dIDRequest, request)
        headers['Accept'] = 'application/json'
        headers['user-agent'] = self.sdk_configuration.user_agent
        
        client = self.sdk_configuration.security_client
        
        http_res = client.request('GET', url, params=query_params, data=data, files=form, headers=headers)
        content_type = http_res.headers.get('Content-Type')

        res = operations.GetModels3dIDResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 200:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.GetModels3dID200ApplicationJSON])
                res.get_models_3d_id_200_application_json_object = out
            else:
                raise errors.SDKError(f'unknown content-type received: {content_type}', http_res.status_code, http_res.text, http_res)

        return res

    
    def get_platform_models(self, limit: Optional[int] = None, offset: Optional[int] = None) -> operations.GetPlatformModelsResponse:
        r"""List Platform Models
        Get a list of public Platform Models available for use with generations.
        """
        request = operations.GetPlatformModelsRequest(
            limit=limit,
            offset=offset,
        )
        
        base_url = utils.template_url(*self.sdk_configuration.get_server_details())
        
        url = base_url + '/platformModels'
        headers = {}
        query_params = utils.get_query_params(operations.GetPlatformModelsRequest, request)
        headers['Accept'] = 'application/json'
        headers['user-agent'] = self.sdk_configuration.user_agent
        
        client = self.sdk_configuration.security_client
        
        http_res = client.request('GET', url, params=query_params, headers=headers)
        content_type = http_res.headers.get('Content-Type')

        res = operations.GetPlatformModelsResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 200:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.GetPlatformModels200ApplicationJSON])
                res.get_platform_models_200_application_json_object = out
            else:
                raise errors.SDKError(f'unknown content-type received: {content_type}', http_res.status_code, http_res.text, http_res)

        return res

    
    def post_models_3d_upload(self, request: operations.PostModels3dUploadRequestBody) -> operations.PostModels3dUploadResponse:
        r"""Upload 3D Model
        This endpoint returns presigned details to upload a 3D model to S3
        """
        base_url = utils.template_url(*self.sdk_configuration.get_server_details())
        
        url = base_url + '/models-3d/upload'
        headers = {}
        req_content_type, data, form = utils.serialize_request_body(request, "request", False, True, 'json')
        if req_content_type not in ('multipart/form-data', 'multipart/mixed'):
            headers['content-type'] = req_content_type
        headers['Accept'] = 'application/json'
        headers['user-agent'] = self.sdk_configuration.user_agent
        
        client = self.sdk_configuration.security_client
        
        http_res = client.request('POST', url, data=data, files=form, headers=headers)
        content_type = http_res.headers.get('Content-Type')

        res = operations.PostModels3dUploadResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 200:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.PostModels3dUpload200ApplicationJSON])
                res.post_models_3d_upload_200_application_json_object = out
            else:
                raise errors.SDKError(f'unknown content-type received: {content_type}', http_res.status_code, http_res.text, http_res)

        return res

    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import requests as requests_http
from dataclasses_json import Undefined, dataclass_json
from leonardoaisdk import utils
from typing import Optional


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class CreateVariationUpscaleRequestBody:
    r"""Query parameters are provided in the request body as a JSON object"""
    id: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('id') }})
    



@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class CreateVariationUpscale200ApplicationJSONSDUpscaleJobOutput:
    api_credit_cost: Optional[int] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('apiCreditCost') }})
    r"""API Credits Cost for Upscale Variation. Available for Production API Users."""
    id: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('id'), 'exclude': lambda f: f is None }})
    



@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class CreateVariationUpscale200ApplicationJSON:
    r"""Responses for POST /variations/upscale"""
    sd_upscale_job: Optional[CreateVariationUpscale200ApplicationJSONSDUpscaleJobOutput] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('sdUpscaleJob') }})
    



@dataclasses.dataclass
class CreateVariationUpscaleResponse:
    content_type: str = dataclasses.field()
    r"""HTTP response content type for this operation"""
    status_code: int = dataclasses.field()
    r"""HTTP response status code for this operation"""
    create_variation_upscale_200_application_json_object: Optional[CreateVariationUpscale200ApplicationJSON] = dataclasses.field(default=None)
    r"""Responses for POST /variations/upscale"""
    raw_response: Optional[requests_http.Response] = dataclasses.field(default=None)
    r"""Raw HTTP response; suitable for custom response parsing"""
    




"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum

class SdGenerationSchedulers(str, Enum):
    r"""The scheduler to generate images with. Defaults to EULER_DISCRETE if not specified."""
    KLMS = 'KLMS'
    EULER_ANCESTRAL_DISCRETE = 'EULER_ANCESTRAL_DISCRETE'
    EULER_DISCRETE = 'EULER_DISCRETE'
    DDIM = 'DDIM'
    DPM_SOLVER = 'DPM_SOLVER'
    PNDM = 'PNDM'
    LEONARDO = 'LEONARDO'



"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from .createdataset import *
from .creategeneration import *
from .createmodel import *
from .createvariationnobg import *
from .createvariationupscale import *
from .delete_generations_texture_id_ import *
from .delete_models_3d_id_ import *
from .deletedatasetbyid import *
from .deletegenerationbyid import *
from .deleteinitimagebyid import *
from .deletemodelbyid import *
from .get_elements import *
from .get_generations_texture_id_ import *
from .get_generations_texture_model_modelid_ import *
from .get_models_3d_id_ import *
from .get_models_3d_user_userid_ import *
from .get_platformmodels import *
from .getdatasetbyid import *
from .getgenerationbyid import *
from .getgenerationsbyuserid import *
from .getinitimagebyid import *
from .getmodelbyid import *
from .getuserself import *
from .getvariationbyid import *
from .post_generations_texture import *
from .post_models_3d_upload import *
from .post_variations_unzoom import *
from .uploaddatasetimage import *
from .uploaddatasetimagefromgen import *
from .uploadinitimage import *

__all__ = ["CreateDataset200ApplicationJSON","CreateDataset200ApplicationJSONDatasets","CreateDatasetRequestBody","CreateDatasetResponse","CreateGeneration200ApplicationJSON","CreateGeneration200ApplicationJSONSDGenerationOutput","CreateGenerationRequestBody","CreateGenerationResponse","CreateModel200ApplicationJSON","CreateModel200ApplicationJSONSDTrainingOutput","CreateModelRequestBody","CreateModelResponse","CreateVariationNoBG200ApplicationJSON","CreateVariationNoBG200ApplicationJSONSDUpscaleJobOutput","CreateVariationNoBGRequestBody","CreateVariationNoBGResponse","CreateVariationUpscale200ApplicationJSON","CreateVariationUpscale200ApplicationJSONSDUpscaleJobOutput","CreateVariationUpscaleRequestBody","CreateVariationUpscaleResponse","DeleteDatasetByID200ApplicationJSON","DeleteDatasetByID200ApplicationJSONDatasets","DeleteDatasetByIDRequest","DeleteDatasetByIDResponse","DeleteGenerationByID200ApplicationJSON","DeleteGenerationByID200ApplicationJSONGenerations","DeleteGenerationByIDRequest","DeleteGenerationByIDResponse","DeleteGenerationsTextureID200ApplicationJSON","DeleteGenerationsTextureID200ApplicationJSONModelAssetTextureGenerations","DeleteGenerationsTextureIDRequest","DeleteGenerationsTextureIDRequestBody","DeleteGenerationsTextureIDResponse","DeleteInitImageByID200ApplicationJSON","DeleteInitImageByID200ApplicationJSONInitImages","DeleteInitImageByIDRequest","DeleteInitImageByIDResponse","DeleteModelByID200ApplicationJSON","DeleteModelByID200ApplicationJSONCustomModels","DeleteModelByIDRequest","DeleteModelByIDResponse","DeleteModels3dID200ApplicationJSON","DeleteModels3dID200ApplicationJSONModelAssets","DeleteModels3dIDRequest","DeleteModels3dIDRequestBody","DeleteModels3dIDResponse","GetDatasetByID200ApplicationJSON","GetDatasetByID200ApplicationJSONDatasets","GetDatasetByID200ApplicationJSONDatasetsDatasetImages","GetDatasetByIDRequest","GetDatasetByIDResponse","GetElements200ApplicationJSON","GetElements200ApplicationJSONLoras","GetElementsResponse","GetGenerationByID200ApplicationJSON","GetGenerationByID200ApplicationJSONGenerations","GetGenerationByID200ApplicationJSONGenerationsGeneratedImages","GetGenerationByID200ApplicationJSONGenerationsGeneratedImagesGeneratedImageVariationGeneric","GetGenerationByID200ApplicationJSONGenerationsGenerationElements","GetGenerationByID200ApplicationJSONGenerationsGenerationElementsLoras","GetGenerationByIDRequest","GetGenerationByIDResponse","GetGenerationsByUserID200ApplicationJSON","GetGenerationsByUserID200ApplicationJSONGenerations","GetGenerationsByUserID200ApplicationJSONGenerationsGeneratedImages","GetGenerationsByUserID200ApplicationJSONGenerationsGeneratedImagesGeneratedImageVariationGeneric","GetGenerationsByUserID200ApplicationJSONGenerationsGenerationElements","GetGenerationsByUserID200ApplicationJSONGenerationsGenerationElementsElements","GetGenerationsByUserIDRequest","GetGenerationsByUserIDResponse","GetGenerationsTextureID200ApplicationJSON","GetGenerationsTextureID200ApplicationJSONModelAssetTextureGenerations","GetGenerationsTextureID200ApplicationJSONModelAssetTextureGenerationsModelAssetTextureImages","GetGenerationsTextureIDRequest","GetGenerationsTextureIDRequestBody","GetGenerationsTextureIDResponse","GetGenerationsTextureModelModelID200ApplicationJSON","GetGenerationsTextureModelModelID200ApplicationJSONModelAssetTextureGenerations","GetGenerationsTextureModelModelID200ApplicationJSONModelAssetTextureGenerationsModelAssetTextureImages","GetGenerationsTextureModelModelIDRequest","GetGenerationsTextureModelModelIDRequestBody","GetGenerationsTextureModelModelIDResponse","GetInitImageByID200ApplicationJSON","GetInitImageByID200ApplicationJSONInitImages","GetInitImageByIDRequest","GetInitImageByIDResponse","GetModelByID200ApplicationJSON","GetModelByID200ApplicationJSONCustomModels","GetModelByIDRequest","GetModelByIDResponse","GetModels3dID200ApplicationJSON","GetModels3dID200ApplicationJSONModelAssets","GetModels3dIDRequest","GetModels3dIDRequestBody","GetModels3dIDResponse","GetModels3dUserUserID200ApplicationJSON","GetModels3dUserUserID200ApplicationJSONModelAssets","GetModels3dUserUserIDRequest","GetModels3dUserUserIDRequestBody","GetModels3dUserUserIDResponse","GetPlatformModels200ApplicationJSON","GetPlatformModels200ApplicationJSONCustomModels","GetPlatformModels200ApplicationJSONCustomModelsGeneratedImages","GetPlatformModelsRequest","GetPlatformModelsResponse","GetUserSelf200ApplicationJSON","GetUserSelf200ApplicationJSONUserDetails","GetUserSelf200ApplicationJSONUserDetailsUsers","GetUserSelfResponse","GetVariationByID200ApplicationJSON","GetVariationByID200ApplicationJSONGeneratedImageVariationGeneric","GetVariationByIDRequest","GetVariationByIDResponse","PostGenerationsTexture200ApplicationJSON","PostGenerationsTexture200ApplicationJSONTextureGenerationJobOutput","PostGenerationsTextureRequestBody","PostGenerationsTextureResponse","PostModels3dUpload200ApplicationJSON","PostModels3dUpload200ApplicationJSONModelAssetUploadOutput","PostModels3dUploadRequestBody","PostModels3dUploadResponse","PostVariationsUnzoom200ApplicationJSON","PostVariationsUnzoom200ApplicationJSONSDUnzoomOutput","PostVariationsUnzoomRequestBody","PostVariationsUnzoomResponse","UploadDatasetImage200ApplicationJSON","UploadDatasetImage200ApplicationJSONDatasetUploadOutput","UploadDatasetImageFromGen200ApplicationJSON","UploadDatasetImageFromGen200ApplicationJSONDatasetGenUploadOutput","UploadDatasetImageFromGenRequest","UploadDatasetImageFromGenRequestBody","UploadDatasetImageFromGenResponse","UploadDatasetImageRequest","UploadDatasetImageRequestBody","UploadDatasetImageResponse","UploadInitImage200ApplicationJSON","UploadInitImage200ApplicationJSONInitImageUploadOutput","UploadInitImageRequestBody","UploadInitImageResponse"]



"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import requests as requests_http
from ..shared import custom_model_type as shared_custom_model_type
from ..shared import sd_versions as shared_sd_versions
from ..shared import strength as shared_strength
from dataclasses_json import Undefined, dataclass_json
from leonardoaisdk import utils
from typing import Optional


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class CreateModelRequestBody:
    r"""Query parameters to be provided in the request body as a JSON object"""
    dataset_id: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('datasetId') }})
    r"""The ID of the dataset to train the model on."""
    instance_prompt: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('instance_prompt') }})
    r"""The instance prompt to use during training."""
    name: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('name') }})
    r"""The name of the model."""
    description: Optional[str] = dataclasses.field(default='', metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('description') }})
    r"""The description of the model."""
    model_type: Optional[shared_custom_model_type.CustomModelType] = dataclasses.field(default=shared_custom_model_type.CustomModelType.GENERAL, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('modelType'), 'exclude': lambda f: f is None }})
    r"""The category the most accurately reflects the model."""
    nsfw: Optional[bool] = dataclasses.field(default=False, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('nsfw') }})
    r"""Whether or not the model is NSFW."""
    resolution: Optional[int] = dataclasses.field(default=512, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('resolution') }})
    r"""The resolution for training. Must be 512 or 768."""
    sd_version: Optional[shared_sd_versions.SdVersions] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('sd_Version'), 'exclude': lambda f: f is None }})
    r"""The base version of stable diffusion to use if not using a custom model. v1_5 is 1.5, v2 is 2.1, if not specified it will default to v1_5."""
    strength: Optional[shared_strength.Strength] = dataclasses.field(default=shared_strength.Strength.MEDIUM, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('strength'), 'exclude': lambda f: f is None }})
    r"""When training using the PIXEL_ART model type, this influences the training strength."""
    



@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class CreateModel200ApplicationJSONSDTrainingOutput:
    api_credit_cost: Optional[int] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('apiCreditCost') }})
    r"""API Credits Cost for Model Training. Available for Production API Users."""
    custom_model_id: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('customModelId'), 'exclude': lambda f: f is None }})
    



@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class CreateModel200ApplicationJSON:
    r"""Responses for POST /models"""
    sd_training_job: Optional[CreateModel200ApplicationJSONSDTrainingOutput] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('sdTrainingJob') }})
    



@dataclasses.dataclass
class CreateModelResponse:
    content_type: str = dataclasses.field()
    r"""HTTP response content type for this operation"""
    status_code: int = dataclasses.field()
    r"""HTTP response status code for this operation"""
    create_model_200_application_json_object: Optional[CreateModel200ApplicationJSON] = dataclasses.field(default=None)
    r"""Responses for POST /models"""
    raw_response: Optional[requests_http.Response] = dataclasses.field(default=None)
    r"""Raw HTTP response; suitable for custom response parsing"""
    




"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from .sdkconfiguration import SDKConfiguration
from leonardoaisdk import utils
from leonardoaisdk.models import errors, operations
from typing import Optional

class Dataset:
    sdk_configuration: SDKConfiguration

    def __init__(self, sdk_config: SDKConfiguration) -> None:
        self.sdk_configuration = sdk_config
        
    
    def create_dataset(self, request: operations.CreateDatasetRequestBody) -> operations.CreateDatasetResponse:
        r"""Create a Dataset
        This endpoint creates a new dataset
        """
        base_url = utils.template_url(*self.sdk_configuration.get_server_details())
        
        url = base_url + '/datasets'
        headers = {}
        req_content_type, data, form = utils.serialize_request_body(request, "request", False, False, 'json')
        if req_content_type not in ('multipart/form-data', 'multipart/mixed'):
            headers['content-type'] = req_content_type
        if data is None and form is None:
            raise Exception('request body is required')
        headers['Accept'] = 'application/json'
        headers['user-agent'] = self.sdk_configuration.user_agent
        
        client = self.sdk_configuration.security_client
        
        http_res = client.request('POST', url, data=data, files=form, headers=headers)
        content_type = http_res.headers.get('Content-Type')

        res = operations.CreateDatasetResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 200:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.CreateDataset200ApplicationJSON])
                res.create_dataset_200_application_json_object = out
            else:
                raise errors.SDKError(f'unknown content-type received: {content_type}', http_res.status_code, http_res.text, http_res)

        return res

    
    def delete_dataset_by_id(self, id: str) -> operations.DeleteDatasetByIDResponse:
        r"""Delete a Single Dataset by ID
        This endpoint deletes the specific dataset
        """
        request = operations.DeleteDatasetByIDRequest(
            id=id,
        )
        
        base_url = utils.template_url(*self.sdk_configuration.get_server_details())
        
        url = utils.generate_url(operations.DeleteDatasetByIDRequest, base_url, '/datasets/{id}', request)
        headers = {}
        headers['Accept'] = 'application/json'
        headers['user-agent'] = self.sdk_configuration.user_agent
        
        client = self.sdk_configuration.security_client
        
        http_res = client.request('DELETE', url, headers=headers)
        content_type = http_res.headers.get('Content-Type')

        res = operations.DeleteDatasetByIDResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 200:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.DeleteDatasetByID200ApplicationJSON])
                res.delete_dataset_by_id_200_application_json_object = out
            else:
                raise errors.SDKError(f'unknown content-type received: {content_type}', http_res.status_code, http_res.text, http_res)

        return res

    
    def get_dataset_by_id(self, id: str) -> operations.GetDatasetByIDResponse:
        r"""Get a Single Dataset by ID
        This endpoint gets the specific dataset
        """
        request = operations.GetDatasetByIDRequest(
            id=id,
        )
        
        base_url = utils.template_url(*self.sdk_configuration.get_server_details())
        
        url = utils.generate_url(operations.GetDatasetByIDRequest, base_url, '/datasets/{id}', request)
        headers = {}
        headers['Accept'] = 'application/json'
        headers['user-agent'] = self.sdk_configuration.user_agent
        
        client = self.sdk_configuration.security_client
        
        http_res = client.request('GET', url, headers=headers)
        content_type = http_res.headers.get('Content-Type')

        res = operations.GetDatasetByIDResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 200:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.GetDatasetByID200ApplicationJSON])
                res.get_dataset_by_id_200_application_json_object = out
            else:
                raise errors.SDKError(f'unknown content-type received: {content_type}', http_res.status_code, http_res.text, http_res)

        return res

    
    def upload_dataset_image(self, request_body: operations.UploadDatasetImageRequestBody, dataset_id: str) -> operations.UploadDatasetImageResponse:
        r"""Upload dataset image
        This endpoint returns presigned details to upload a dataset image to S3
        """
        request = operations.UploadDatasetImageRequest(
            request_body=request_body,
            dataset_id=dataset_id,
        )
        
        base_url = utils.template_url(*self.sdk_configuration.get_server_details())
        
        url = utils.generate_url(operations.UploadDatasetImageRequest, base_url, '/datasets/{datasetId}/upload', request)
        headers = {}
        req_content_type, data, form = utils.serialize_request_body(request, "request_body", False, False, 'json')
        if req_content_type not in ('multipart/form-data', 'multipart/mixed'):
            headers['content-type'] = req_content_type
        if data is None and form is None:
            raise Exception('request body is required')
        headers['Accept'] = 'application/json'
        headers['user-agent'] = self.sdk_configuration.user_agent
        
        client = self.sdk_configuration.security_client
        
        http_res = client.request('POST', url, data=data, files=form, headers=headers)
        content_type = http_res.headers.get('Content-Type')

        res = operations.UploadDatasetImageResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 200:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.UploadDatasetImage200ApplicationJSON])
                res.upload_dataset_image_200_application_json_object = out
            else:
                raise errors.SDKError(f'unknown content-type received: {content_type}', http_res.status_code, http_res.text, http_res)

        return res

    
    def upload_dataset_image_from_gen(self, request_body: operations.UploadDatasetImageFromGenRequestBody, dataset_id: str) -> operations.UploadDatasetImageFromGenResponse:
        r"""Upload a Single Generated Image to a Dataset
        This endpoint will upload a previously generated image to the dataset
        """
        request = operations.UploadDatasetImageFromGenRequest(
            request_body=request_body,
            dataset_id=dataset_id,
        )
        
        base_url = utils.template_url(*self.sdk_configuration.get_server_details())
        
        url = utils.generate_url(operations.UploadDatasetImageFromGenRequest, base_url, '/datasets/{datasetId}/upload/gen', request)
        headers = {}
        req_content_type, data, form = utils.serialize_request_body(request, "request_body", False, False, 'json')
        if req_content_type not in ('multipart/form-data', 'multipart/mixed'):
            headers['content-type'] = req_content_type
        if data is None and form is None:
            raise Exception('request body is required')
        headers['Accept'] = 'application/json'
        headers['user-agent'] = self.sdk_configuration.user_agent
        
        client = self.sdk_configuration.security_client
        
        http_res = client.request('POST', url, data=data, files=form, headers=headers)
        content_type = http_res.headers.get('Content-Type')

        res = operations.UploadDatasetImageFromGenResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 200:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.UploadDatasetImageFromGen200ApplicationJSON])
                res.upload_dataset_image_from_gen_200_application_json_object = out
            else:
                raise errors.SDKError(f'unknown content-type received: {content_type}', http_res.status_code, http_res.text, http_res)

        return res

    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from .sdkconfiguration import SDKConfiguration
from leonardoaisdk import utils
from leonardoaisdk.models import errors, operations
from typing import Optional

class Variation:
    sdk_configuration: SDKConfiguration

    def __init__(self, sdk_config: SDKConfiguration) -> None:
        self.sdk_configuration = sdk_config
        
    
    def create_variation_no_bg(self, request: operations.CreateVariationNoBGRequestBody) -> operations.CreateVariationNoBGResponse:
        r"""Create no background
        This endpoint will create a no background variation of the provided image ID
        """
        base_url = utils.template_url(*self.sdk_configuration.get_server_details())
        
        url = base_url + '/variations/nobg'
        headers = {}
        req_content_type, data, form = utils.serialize_request_body(request, "request", False, False, 'json')
        if req_content_type not in ('multipart/form-data', 'multipart/mixed'):
            headers['content-type'] = req_content_type
        if data is None and form is None:
            raise Exception('request body is required')
        headers['Accept'] = 'application/json'
        headers['user-agent'] = self.sdk_configuration.user_agent
        
        client = self.sdk_configuration.security_client
        
        http_res = client.request('POST', url, data=data, files=form, headers=headers)
        content_type = http_res.headers.get('Content-Type')

        res = operations.CreateVariationNoBGResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 200:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.CreateVariationNoBG200ApplicationJSON])
                res.create_variation_no_bg_200_application_json_object = out
            else:
                raise errors.SDKError(f'unknown content-type received: {content_type}', http_res.status_code, http_res.text, http_res)

        return res

    
    def create_variation_upscale(self, request: operations.CreateVariationUpscaleRequestBody) -> operations.CreateVariationUpscaleResponse:
        r"""Create upscale
        This endpoint will create an upscale for the provided image ID
        """
        base_url = utils.template_url(*self.sdk_configuration.get_server_details())
        
        url = base_url + '/variations/upscale'
        headers = {}
        req_content_type, data, form = utils.serialize_request_body(request, "request", False, True, 'json')
        if req_content_type not in ('multipart/form-data', 'multipart/mixed'):
            headers['content-type'] = req_content_type
        headers['Accept'] = 'application/json'
        headers['user-agent'] = self.sdk_configuration.user_agent
        
        client = self.sdk_configuration.security_client
        
        http_res = client.request('POST', url, data=data, files=form, headers=headers)
        content_type = http_res.headers.get('Content-Type')

        res = operations.CreateVariationUpscaleResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 200:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.CreateVariationUpscale200ApplicationJSON])
                res.create_variation_upscale_200_application_json_object = out
            else:
                raise errors.SDKError(f'unknown content-type received: {content_type}', http_res.status_code, http_res.text, http_res)

        return res

    
    def get_variation_by_id(self, id: str) -> operations.GetVariationByIDResponse:
        r"""Get variation by ID
        This endpoint will get the variation by ID
        """
        request = operations.GetVariationByIDRequest(
            id=id,
        )
        
        base_url = utils.template_url(*self.sdk_configuration.get_server_details())
        
        url = utils.generate_url(operations.GetVariationByIDRequest, base_url, '/variations/{id}', request)
        headers = {}
        headers['Accept'] = 'application/json'
        headers['user-agent'] = self.sdk_configuration.user_agent
        
        client = self.sdk_configuration.security_client
        
        http_res = client.request('GET', url, headers=headers)
        content_type = http_res.headers.get('Content-Type')

        res = operations.GetVariationByIDResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 200:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.GetVariationByID200ApplicationJSON])
                res.get_variation_by_id_200_application_json_object = out
            else:
                raise errors.SDKError(f'unknown content-type received: {content_type}', http_res.status_code, http_res.text, http_res)

        return res

    
    def post_variations_unzoom(self, request: operations.PostVariationsUnzoomRequestBody) -> operations.PostVariationsUnzoomResponse:
        r"""Create unzoom
        This endpoint will create an unzoom variation for the provided image ID
        """
        base_url = utils.template_url(*self.sdk_configuration.get_server_details())
        
        url = base_url + '/variations/unzoom'
        headers = {}
        req_content_type, data, form = utils.serialize_request_body(request, "request", False, True, 'json')
        if req_content_type not in ('multipart/form-data', 'multipart/mixed'):
            headers['content-type'] = req_content_type
        headers['Accept'] = 'application/json'
        headers['user-agent'] = self.sdk_configuration.user_agent
        
        client = self.sdk_configuration.security_client
        
        http_res = client.request('POST', url, data=data, files=form, headers=headers)
        content_type = http_res.headers.get('Content-Type')

        res = operations.PostVariationsUnzoomResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 200:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.PostVariationsUnzoom200ApplicationJSON])
                res.post_variations_unzoom_200_application_json_object = out
            else:
                raise errors.SDKError(f'unknown content-type received: {content_type}', http_res.status_code, http_res.text, http_res)

        return res

    